@@ -5,7 +5,7 @@
 
     Data structures for message catalogs.
 
-    :copyright: (c) 2013-2019 by the Babel Team.
+    :copyright: (c) 2013-2020 by the Babel Team.
     :license: BSD, see LICENSE for more details.
 """
 
@@ -807,7 +807,7 @@ class Catalog(object):
                 if key in messages:
                     _merge(message, key, key)
                 else:
-                    if no_fuzzy_matching is False:
+                    if not no_fuzzy_matching:
                         # do some fuzzy matching with difflib
                         if isinstance(key, tuple):
                             matchkey = key[0]  # just the msgid, no context
